@@ -1,6 +1,6 @@
 /*
     findep
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ help (FILE        *fp,
 {
   g_fprintf (fp,
 "findep "VERSION" ("BUILD_ENVIRONMENT")\n"
-"copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org\n"
+"copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org\n"
 "\n"
 "Usage: %s command [option...] [file|string...]\n"
 "\n"
@@ -798,10 +798,7 @@ main (int   argc,
                 }
               if (mnemonic)
                 {
-                  gboolean lookup;
-
-                  lookup = g_hash_table_lookup (ghash_entry, mnemonic);
-                  if (lookup)
+                  if (g_hash_table_lookup (ghash_entry, mnemonic))
                     {
                       glist = g_list_append (glist,
                                     g_strdup_printf ("Entry Point : %08x %s\n",
