@@ -143,7 +143,7 @@ ia32_module_create_library (Ia32Process     *process,
             + sizeof (ImageSectionHeader);
   leng_code = 0;
   leng_data = sizeof (ImageExportDirectory) + g_strlen (osdll->name) + 1;
-  for (i = 0; osdll->exports[i].func; i++)
+  for (i = 0; osdll->exports[i].argument != G_MAXINT; i++)
     {
       if (osdll->exports[i].argument < 0)
         leng_code -= osdll->exports[i].argument;
@@ -240,7 +240,7 @@ ia32_module_create_library (Ia32Process     *process,
                                                 - GPOINTER_TO_UINT (image));
   g_strcpy (q, osdll->name);
   q += g_strlen (osdll->name) + 1;
-  for (i = 0; osdll->exports[i].func; i++)
+  for (i = 0; osdll->exports[i].argument != G_MAXINT; i++)
     {
       gint index;
 
@@ -306,13 +306,6 @@ ia32_module_load_system_library (Ia32Process *process,
 }
 
 
-static gboolean
-ia32_module_func (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
 /*  ja:イメージをロードする
     process,プロセス
        file,イメージ名
@@ -458,8 +451,9 @@ ia32_module_load_library (Ia32Process *process,
                       osdll.exports[n].argument = 0;
                       osdll.exports[n].ordinal = itd_get_ordinal (ilt)
                                                     & ~PEIMAGE_ORDINAL_FLAG;
-                      osdll.exports[n].name = "";
-                      osdll.exports[n].func = ia32_module_func;
+                      osdll.exports[n].name
+                        = g_strdup_printf ("#%d", osdll.exports[n].ordinal);
+                      osdll.exports[n].func = NULL;
                       n++;
                     }
                   else if (itd_get_address_of_data (ilt)
@@ -477,8 +471,9 @@ ia32_module_load_library (Ia32Process *process,
                                             + itd_get_address_of_data (ilt));
                             osdll.exports[n].argument = 0;
                             osdll.exports[n].ordinal = G_MAXUINT16;
-                            osdll.exports[n].name = iibn_get_name (iibn);
-                            osdll.exports[n].func = ia32_module_func;
+                            osdll.exports[n].name
+                                            = g_strdup (iibn_get_name (iibn));
+                            osdll.exports[n].func = NULL;
                             n++;
                             break;
                           }
@@ -488,11 +483,13 @@ ia32_module_load_library (Ia32Process *process,
                 }
               osdll.exports = g_realloc (osdll.exports,
                                                 (n + 1) * sizeof (Ia32Export));
-              osdll.exports[n].argument = 0;
+              osdll.exports[n].argument = G_MAXINT;
               osdll.exports[n].ordinal = 0;
               osdll.exports[n].name = NULL;
               osdll.exports[n].func = NULL;
               import = ia32_module_create_library (process, &osdll);
+              for (i = 0; i < n; i++)
+                g_free (osdll.exports[n].name);
               g_free (osdll.exports);
             }
           if (import != IA32_MEMORY_NULL)
