@@ -1,6 +1,6 @@
 /*
     IA32
-    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,29 +18,8 @@
 #include "dbgeng.h"
 
 
-/* DebugConnect ordinal = 1, argument = 12 */
-static gboolean dbgeng_DebugConnect (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
-/* DebugConnectWide ordinal = 2, argument = 12 */
-static gboolean dbgeng_DebugConnectWide (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
-/* DebugCreate ordinal = 3, argument = 8 */
-static gboolean dbgeng_DebugCreate (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
 Ia32Export ia32_dbgeng_exports[] = {
-{12,    1, "DebugConnect",     dbgeng_DebugConnect},
-{12,    2, "DebugConnectWide", dbgeng_DebugConnectWide},
-{ 8,    3, "DebugCreate",      dbgeng_DebugCreate},
-{ 0,    0, NULL,               NULL}};
+{12, 1, "DebugConnect",     NULL},
+{12, 2, "DebugConnectWide", NULL},
+{ 8, 3, "DebugCreate",      NULL},
+{G_MAXINT, 0, NULL, NULL}};
