@@ -1,6 +1,6 @@
 /*
     IA32
-    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,29 +18,8 @@
 #include "dpx.h"
 
 
-/* DpxFreeMemory ordinal = 1, argument = 4 */
-static gboolean dpx_DpxFreeMemory (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
-/* DpxNewJob ordinal = 2, argument = 8 */
-static gboolean dpx_DpxNewJob (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
-/* DpxRestoreJob ordinal = 3, argument = 8 */
-static gboolean dpx_DpxRestoreJob (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
 Ia32Export ia32_dpx_exports[] = {
-{ 4,    1, "DpxFreeMemory", dpx_DpxFreeMemory},
-{ 8,    2, "DpxNewJob",     dpx_DpxNewJob},
-{ 8,    3, "DpxRestoreJob", dpx_DpxRestoreJob},
-{ 0,    0, NULL,            NULL}};
+{4, 1, "DpxFreeMemory", NULL},
+{8, 2, "DpxNewJob",     NULL},
+{8, 3, "DpxRestoreJob", NULL},
+{G_MAXINT, 0, NULL, NULL}};
