@@ -1,6 +1,6 @@
 /*
     IA32
-    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,21 +18,7 @@
 #include "shfolder.h"
 
 
-/* SHGetFolderPathA ordinal = 1, argument = 20 */
-static gboolean shfolder_SHGetFolderPathA (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
-/* SHGetFolderPathW ordinal = 2, argument = 20 */
-static gboolean shfolder_SHGetFolderPathW (Ia32Thread *thread)
-{
-  return FALSE;
-}
-
-
 Ia32Export ia32_shfolder_exports[] = {
-{20,    1, "SHGetFolderPathA", shfolder_SHGetFolderPathA},
-{20,    2, "SHGetFolderPathW", shfolder_SHGetFolderPathW},
-{ 0,    0, NULL,               NULL}};
+{20, 1, "SHGetFolderPathA", NULL},
+{20, 2, "SHGetFolderPathW", NULL},
+{G_MAXINT, 0, NULL, NULL}};
