@@ -1,6 +1,6 @@
 /*
     gcommon
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1266,6 +1266,7 @@ gchar *g_filename_display_basename (const gchar *filename);
 # define g_unichar_totitle(c) (c)
 # define g_unichar_digit_value(c) g_ascii_digit_value(c)
 # define g_unichar_xdigit_value(c) g_ascii_xdigit_value(c)
+gchar *g_utf8_next_char (const gchar *p);
 gunichar g_utf8_get_char_validated (const gchar *p, gssize max_len);
 gchar *g_utf8_strup (const gchar *str, gssize len);
 gchar *g_utf8_strdown (const gchar *str, gssize len);
@@ -1328,6 +1329,85 @@ gchar *g_compute_checksum_for_string (GChecksumType checksum_type, const gchar *
 #endif /* not GLIB_CHECK_VERSION(2,4,0) */
 
 
+/******************************************************************************
+* Date and Time Functions                                                     *
+******************************************************************************/
+#ifndef G_USEC_PER_SEC
+# define G_USEC_PER_SEC 1000000
+#endif /* not G_USEC_PER_SEC */
+#ifdef USE_GTK_EMULATE
+typedef struct _GTimeVal
+{
+  glong tv_sec;
+  glong tv_usec;
+} GTimeVal;
+
+
+void g_get_current_time (GTimeVal *result);
+void g_usleep (gulong microseconds);
+#endif /* USE_GTK_EMULATE */
+#if ! GLIB_CHECK_VERSION(2,28,0)
+gint64 g_get_monotonic_time (void);
+gint64 g_get_real_time (void);
+#endif /* not GLIB_CHECK_VERSION(2,28,0) */
+
+
+/******************************************************************************
+* GDateTime                                                                   *
+******************************************************************************/
+#ifndef G_TIME_SPAN_DAY
+# define G_TIME_SPAN_DAY         (G_GINT64_CONSTANT (86400000000))
+#endif /* not G_TIME_SPAN_DAY */
+#ifndef G_TIME_SPAN_HOUR
+# define G_TIME_SPAN_HOUR        (G_GINT64_CONSTANT (3600000000))
+#endif /* not G_TIME_SPAN_HOUR */
+#ifndef G_TIME_SPAN_MINUTE
+# define G_TIME_SPAN_MINUTE      (G_GINT64_CONSTANT (60000000))
+#endif /* not G_TIME_SPAN_MINUTE */
+#ifndef G_TIME_SPAN_SECOND
+# define G_TIME_SPAN_SECOND      (G_GINT64_CONSTANT (1000000))
+#endif /* not G_TIME_SPAN_SECOND */
+#ifndef G_TIME_SPAN_MILLISECOND
+# define G_TIME_SPAN_MILLISECOND (G_GINT64_CONSTANT (1000))
+#endif /* not G_TIME_SPAN_MILLISECOND */
+#if ! GLIB_CHECK_VERSION(2,26,0)
+typedef gint64 GTimeSpan;
+typedef struct _GDateTime GDateTime;
+
+
+void g_date_time_unref (GDateTime *datetime);
+GDateTime *g_date_time_ref (GDateTime *datetime);
+GDateTime *g_date_time_new_now_utc (void);
+GDateTime *g_date_time_new_from_unix_utc (gint64 t);
+GDateTime *g_date_time_new_from_timeval_utc (const GTimeVal *tv);
+GDateTime *g_date_time_new_utc (gint year, gint month, gint day, gint hour, gint minute, gdouble seconds);
+GDateTime *g_date_time_add (GDateTime *datetime, GTimeSpan timespan);
+GDateTime *g_date_time_add_years (GDateTime *datetime, gint years);
+GDateTime *g_date_time_add_months (GDateTime *datetime, gint months);
+GDateTime *g_date_time_add_weeks (GDateTime *datetime, gint weeks);
+GDateTime *g_date_time_add_days (GDateTime *datetime, gint days);
+GDateTime *g_date_time_add_hours (GDateTime *datetime, gint hours);
+GDateTime *g_date_time_add_minutes (GDateTime *datetime, gint minutes);
+GDateTime *g_date_time_add_seconds (GDateTime *datetime, gdouble seconds);
+GDateTime *g_date_time_add_full (GDateTime *datetime, gint years, gint months, gint days, gint hours, gint minutes, gdouble seconds);
+gint g_date_time_compare (gconstpointer dt1, gconstpointer dt2);
+GTimeSpan g_date_time_difference (GDateTime *end, GDateTime *begin);
+guint g_date_time_hash (gconstpointer datetime);
+gboolean g_date_time_equal (gconstpointer dt1, gconstpointer dt2);
+void g_date_time_get_ymd (GDateTime *datetime, gint *year, gint *month, gint *day);
+gint g_date_time_get_year (GDateTime *datetime);
+gint g_date_time_get_month (GDateTime *datetime);
+gint g_date_time_get_day_of_month (GDateTime *datetime);
+gint g_date_time_get_hour (GDateTime *datetime);
+gint g_date_time_get_minute (GDateTime *datetime);
+gint g_date_time_get_second (GDateTime *datetime);
+gint g_date_time_get_microsecond (GDateTime *datetime);
+gdouble g_date_time_get_seconds (GDateTime *datetime);
+gint64 g_date_time_to_unix (GDateTime *datetime);
+gboolean g_date_time_to_timeval (GDateTime *datetime, GTimeVal *tv);
+#endif /* not GLIB_CHECK_VERSION(2,26,0) */
+
+
 /******************************************************************************
 * Miscellaneous Utility Functions                                             *
 ******************************************************************************/
@@ -1389,15 +1469,28 @@ typedef enum _GFileTest
 
 gboolean g_file_test (const gchar *file, GFileTest test);
 #endif /* USE_GTK_EMULATE */
+#if ! GLIB_CHECK_VERSION(2,26,0)
+typedef struct stat GStatBuf;
+#endif /* not GLIB_CHECK_VERSION(2,26,0) */
+
+
 #if ! GLIB_CHECK_VERSION(2,22,0)
-# define g_mapped_file_unref g_mapped_file_free
+# define g_mapped_file_unref(file) g_mapped_file_free(file)
 #endif /* not GLIB_CHECK_VERSION(2,22,0) */
 #if ! GLIB_CHECK_VERSION(2,6,0)
 # define g_open open
 # define g_rename rename
-# define g_mkdir mkdir
+# ifdef G_OS_WIN32
+gint g_mkdir (const gchar *filename, gint mode);
+# else /* not G_OS_WIN32 */
+#  define g_mkdir mkdir
+# endif /* not G_OS_WIN32 */
 # define g_stat stat
-# define g_lstat lstat
+# ifdef HAVE_LSTAT
+#  define g_lstat lstat
+# else /* not HAVE_LSTAT */
+#  define g_lstat stat
+# endif /* not HAVE_LSTAT */
 # define g_unlink unlink
 # define g_remove remove
 # define g_rmdir rmdir
@@ -1405,13 +1498,19 @@ gboolean g_file_test (const gchar *file, GFileTest test);
 # define g_freopen freopen
 #endif /* not GLIB_CHECK_VERSION(2,6,0) */
 #if ! GLIB_CHECK_VERSION(2,8,0)
-# define g_chmod chmod
-# define g_access access
-# define g_creat creat
-# define g_chdir chdir
+gint g_chmod (const gchar *filename, gint mode);
+gint g_access (const gchar *filename, gint mode);
+gint g_creat (const gchar *filename, gint mode);
+gint g_chdir (const gchar *path);
 #endif /* not GLIB_CHECK_VERSION(2,8,0) */
 #if ! GLIB_CHECK_VERSION(2,18,0)
-# define g_utime utime
+# ifdef G_OS_WIN32
+# include <sys/utime.h>
+# endif /* G_OS_WIN32 */
+# ifdef HAVE_UTIME_H
+# include <utime.h>
+# endif /* HAVE_UTIME_H */
+gint g_utime (const gchar *filename, struct utimbuf *utb);
 #endif /* not GLIB_CHECK_VERSION(2,18,0) */
 
 
@@ -1428,6 +1527,32 @@ void g_dir_close (GDir *dir);
 #endif /* USE_GTK_EMULATE */
 
 
+/******************************************************************************
+* URI Utilities                                                               *
+******************************************************************************/
+#ifndef G_URI_RESERVED_CHARS_GENERIC_DELIMITERS
+# define G_URI_RESERVED_CHARS_GENERIC_DELIMITERS ":/?#[]@"
+#endif /* not G_URI_RESERVED_CHARS_GENERIC_DELIMITERS */
+#ifndef G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS
+# define G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS "!$&'()*+,;="
+#endif /* not G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS */
+#ifndef G_URI_RESERVED_CHARS_ALLOWED_IN_PATH_ELEMENT
+# define G_URI_RESERVED_CHARS_ALLOWED_IN_PATH_ELEMENT G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS ":@"
+#endif /* not G_URI_RESERVED_CHARS_ALLOWED_IN_PATH_ELEMENT */
+#ifndef G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS
+# define G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS G_URI_RESERVED_CHARS_ALLOWED_IN_PATH_ELEMENT "/"
+#endif /* not G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS */
+#ifndef G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS
+# define G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS ":"
+#endif /* not G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS */
+#if ! GLIB_CHECK_VERSION(2,16,0)
+gchar *g_uri_parse_scheme (const gchar *uri);
+gchar *g_uri_escape_string (const gchar *unescaped, const gchar *reserved_chars_allowed, gboolean allow_utf8);
+gchar *g_uri_unescape_string (const gchar *escaped_string, const gchar *illegal_characters);
+gchar *g_uri_unescape_segment (const gchar *escaped_string, const gchar *escaped_string_end, const gchar *illegal_characters);
+#endif /* not GLIB_CHECK_VERSION(2,16,0) */
+
+
 /******************************************************************************
 * Windows Compatibility Functions                                             *
 ******************************************************************************/
@@ -1500,6 +1625,12 @@ gpointer g_hash_table_lookup (GHashTable *hash_table, gconstpointer key);
 void g_hash_table_foreach (GHashTable *hash_table, GHFunc func, gpointer user_data);
 gboolean g_hash_table_remove (GHashTable *hash_table, gconstpointer key);
 guint g_hash_table_foreach_remove (GHashTable *hash_table, GHRFunc func, gpointer user_data);
+#endif /* USE_GTK_EMULATE */
+#if ! GLIB_CHECK_VERSION(2,14,0)
+GList *g_hash_table_get_keys (GHashTable *hash_table);
+GList *g_hash_table_get_values (GHashTable *hash_table);
+#endif /* not GLIB_CHECK_VERSION(2,14,0) */
+#ifdef USE_GTK_EMULATE
 void g_hash_table_destroy (GHashTable *hash_table);
 gboolean g_direct_equal (gconstpointer v1, gconstpointer v2);
 guint g_direct_hash (gconstpointer v);
